==> jc-1.4.0.tar.gz: javax/naming/ldap/UnsolicitedNotificationEvent.h <==
// public class javax.naming.ldap.UnsolicitedNotificationEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class be8f050654642ff9 javax_naming_ldap_UnsolicitedNotificationEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_naming_ldap_UnsolicitedNotificationEvent_H_
#define _JC_javax_naming_ldap_UnsolicitedNotificationEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_ldap_UnsolicitedNotification$object;
struct _jc_javax_naming_ldap_UnsolicitedNotificationListener$object;

// Typedefs
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_refs	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_refs;
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_nonrefs	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_nonrefs;
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$refs	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$refs;
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$nonrefs	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$nonrefs;
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$object;

typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$fields_struct	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$fields_struct;
typedef const struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vmethods	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vmethods;
typedef const struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtable	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtable;
typedef const struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype;

// Class fields structure
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_ldap_UnsolicitedNotificationEvent$fields_struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$class_fields;

// Constructors
extern void _jc_javax_naming_ldap_UnsolicitedNotificationEvent$method$_init$71a1d2f8b4b20471(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual methods
extern void _jc_javax_naming_ldap_UnsolicitedNotificationEvent$method$dispatch$88520191276e807a(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_naming_ldap_UnsolicitedNotificationEvent$method$getNotification$79e45561ae7e3804(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ldap_UnsolicitedNotificationEvent$method_info$dispatch$88520191276e807a;
extern _jc_method _jc_javax_naming_ldap_UnsolicitedNotificationEvent$method_info$getNotification$79e45561ae7e3804;

// Virtual methods structure
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vmethods {
	void	(*dispatch$88520191276e807a)(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *, struct _jc_object *);
	struct _jc_object	*(*getNotification$79e45561ae7e3804)(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *);
};

// Vtable
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vmethods	javax_naming_ldap_UnsolicitedNotificationEvent;
};

// Vtype
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype {
	_jc_type			type;
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_refs {
	struct _jc_object	*notice;
};

// Reference instance fields (object)
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$refs {
    _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_refs	javax_naming_ldap_UnsolicitedNotificationEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_nonrefs	javax_naming_ldap_UnsolicitedNotificationEvent;
};

// Object instance structure
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object {
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype	*vtype;
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype _jc_javax_naming_ldap_UnsolicitedNotificationEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ldap_UnsolicitedNotificationEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ldap_UnsolicitedNotificationEvent$class_object;

#endif	/* _JC_javax_naming_ldap_UnsolicitedNotificationEvent_H_ */

==> jc-1.4.6.tar.gz: javax/naming/ldap/UnsolicitedNotificationEvent.h <==
// public class javax.naming.ldap.UnsolicitedNotificationEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class be8f050654642ff9 javax_naming_ldap_UnsolicitedNotificationEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_naming_ldap_UnsolicitedNotificationEvent_H_
#define _JC_javax_naming_ldap_UnsolicitedNotificationEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_ldap_UnsolicitedNotification$object;
struct _jc_javax_naming_ldap_UnsolicitedNotificationListener$object;

// Typedefs
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_refs	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_refs;
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_nonrefs	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_nonrefs;
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$refs	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$refs;
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$nonrefs	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$nonrefs;
typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$object;

typedef struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$fields_struct	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$fields_struct;
typedef const struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vmethods	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vmethods;
typedef const struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtable	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtable;
typedef const struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype;

// Class fields structure
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_ldap_UnsolicitedNotificationEvent$fields_struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$class_fields;

// Constructors
extern void _jc_javax_naming_ldap_UnsolicitedNotificationEvent$method$_init$71a1d2f8b4b20471(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_naming_ldap_UnsolicitedNotificationEvent$method$dispatch$88520191276e807a(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_ldap_UnsolicitedNotificationEvent$method$getNotification$79e45561ae7e3804(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ldap_UnsolicitedNotificationEvent$method_info$dispatch$88520191276e807a;
extern _jc_method _jc_javax_naming_ldap_UnsolicitedNotificationEvent$method_info$getNotification$79e45561ae7e3804;

// Virtual methods structure
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vmethods {
	void	(*dispatch$88520191276e807a)(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getNotification$79e45561ae7e3804)(_jc_env *, struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vmethods	javax_naming_ldap_UnsolicitedNotificationEvent;
};

// Vtype
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype {
	_jc_type			type;
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_refs {
	struct _jc_object	*notice;
};

// Reference instance fields (object)
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$refs {
    _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_refs	javax_naming_ldap_UnsolicitedNotificationEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_naming_ldap_UnsolicitedNotificationEvent$sub_nonrefs	javax_naming_ldap_UnsolicitedNotificationEvent;
};

// Object instance structure
struct _jc_javax_naming_ldap_UnsolicitedNotificationEvent$object {
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype	*vtype;
	_jc_javax_naming_ldap_UnsolicitedNotificationEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ldap_UnsolicitedNotificationEvent$vtype _jc_javax_naming_ldap_UnsolicitedNotificationEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ldap_UnsolicitedNotificationEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ldap_UnsolicitedNotificationEvent$class_object;

#endif	/* _JC_javax_naming_ldap_UnsolicitedNotificationEvent_H_ */
